@@ -18,18 +18,18 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef FRAME_GLOM_H
-#define FRAME_GLOM_H
+#ifndef GLOM_FRAME_GLOM_H
+#define GLOM_FRAME_GLOM_H
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
+#include "window_boxholder.h"
+
 #include <gtkmm/frame.h>
 #include <gtkmm/toggleaction.h>
 #include <libglom/document/bakery/view/view_composite.h>
 #include <libglom/document/document.h>
 
-#include "window_boxholder.h"
-
 #ifndef GLOM_ENABLE_MAEMO
 #include "navigation/box_tables.h"
 #endif
@@ -66,7 +66,7 @@ class Frame_Glom :
   //public GlomBakery::View_Composite<Document>,
   public Base_DB //Inherits from View_Composite.
 {
-public: 
+public:
   Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Frame_Glom();
 
@@ -89,13 +89,12 @@ public:
   void on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>& action);
   void on_menu_file_print();
 
-  void on_menu_Mode_Data();
-  void on_menu_Mode_Find();
-  
-  #ifdef GLOM_ENABLE_MAEMO
+  void on_menu_Mode_Toggle();
+
+  //TODO: Actually put this in the menu for non-maemo too? #ifdef GLOM_ENABLE_MAEMO
   void on_menu_add_record();
-  #endif
-  
+  //#endif
+
   void on_menu_report_selected(const Glib::ustring& report_name);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -114,7 +113,6 @@ public:
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_menu_Reports_EditReports();
-  void on_menu_File_EditPrintLayouts();
   void on_menu_developer_database_preferences();
   void on_menu_developer_fields();
   void do_menu_developer_fields(Gtk::Window& parent);
@@ -131,9 +129,7 @@ public:
   void on_developer_dialog_hide();
 
   void on_dialog_layout_report_hide();
-  void on_dialog_reports_hide();
   void on_dialog_layout_print_hide();
-  void on_dialog_print_layouts_hide();
 
   void on_dialog_add_related_table_request_edit_fields();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -174,7 +170,6 @@ public:
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void export_data_to_vector(Document::type_example_rows& the_vector, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
-  void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
   void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document::type_list_layout_groups& sequence);
 
   /** Show the table again. For instance, if the document has changed, or we want to display it differently.
@@ -192,10 +187,10 @@ public:
    * @param primary_key_value_for_details If specified, switch to the details view, and show this record.
    */
   void show_table(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value_for_details = Gnome::Gda::Value());
-  
+
 protected:
 
-  
+
 
   //virtual void set_document(Document* pDocument); //override
 
@@ -230,10 +225,10 @@ protected:
   void alert_no_table();
 
   //Signal handlers:
-  void on_notebook_find_criteria(const Glib::ustring& where_clause);
+  void on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clause);
   void on_button_quickfind();
   void on_button_find_all();
-  void on_notebook_data_switch_page(GtkNotebookPage* page, guint page_num);
+  void on_notebook_data_switch_page(Gtk::Widget* page, guint page_num);
   void on_notebook_data_record_details_requested(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
   void on_userlevel_changed(AppState::userlevels userlevel);
 
@@ -253,7 +248,7 @@ private:
    * @result Whether to try again.
    */
   bool handle_request_password_connection_error(bool asked_for_password, const ExceptionConnection& ex, bool& database_not_found);
-  
+
   //Member data:
   Glib::ustring m_table_name;
 
@@ -278,22 +273,22 @@ private:
 #endif //GLOM_ENABLE_MAEMO
 
   Notebook_Data m_Notebook_Data;
-  
+
   Gtk::HBox* m_pBox_QuickFind; //Only show this when in Find mode.
   Gtk::Entry* m_pEntry_QuickFind;
   Gtk::Button* m_pButton_QuickFind;
   Notebook_Find m_Notebook_Find;
-  
+
   #ifdef GLOM_ENABLE_MAEMO
   Hildon::StackableWindow m_maemo_window_find;
   #endif
-  
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Developer:
   Window_BoxHolder* m_pDialog_Reports;
   Dialog_Layout_Report* m_pDialogLayoutReport;
   Box_Reports* m_pBox_Reports;
-  
+
   Window_BoxHolder* m_pDialog_PrintLayouts;
   Window_PrintLayout_Edit* m_pDialogLayoutPrint;
   Box_Print_Layouts* m_pBox_PrintLayouts;
@@ -302,7 +297,7 @@ private:
   Dialog_Relationships* m_pDialog_Relationships;
   Dialog_AddRelatedTable* m_dialog_addrelatedtable;
   Dialog_RelationshipsOverview* m_dialog_relationships_overview;
-    
+
   Dialog_ProgressCreating* m_dialog_progess_connection_initialize;
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
@@ -314,4 +309,4 @@ private:
 
 } //namespace Glom
 
-#endif //FRAME_GLOM_H
+#endif // GLOM_FRAME_GLOM_H
