@@ -91,10 +91,6 @@ namespace ConnectionPoolBackends
 "# IPv6 local connections:\n" \
 "host    all         all         ::1/128               md5\n"
 
-#define PORT_POSTGRESQL_SELF_HOSTED_START 5433
-#define PORT_POSTGRESQL_SELF_HOSTED_END 5500
-
-
 #define DEFAULT_CONFIG_PG_HBA_REMOTE_8p3 \
 DEFAULT_CONFIG_PG_HBA_LOCAL_8p3 \
 DEFAULT_CONFIG_PG_HBA_REMOTE_EXTRA
@@ -103,12 +99,12 @@ DEFAULT_CONFIG_PG_HBA_REMOTE_EXTRA
 DEFAULT_CONFIG_PG_HBA_LOCAL_8p3 \
 DEFAULT_CONFIG_PG_HBA_REMOTE_EXTRA
 
-#define PORT_POSTGRESQL_SELF_HOSTED_START 5433
-#define PORT_POSTGRESQL_SELF_HOSTED_END 5500
+static const int PORT_POSTGRESQL_SELF_HOSTED_START = 5433;
+static const int PORT_POSTGRESQL_SELF_HOSTED_END = 5500;
 
-static const char* DEFAULT_CONFIG_PG_IDENT = "";
-static const char* FILENAME_DATA = "data";
-static const char* FILENAME_BACKUP = "backup";
+static const char DEFAULT_CONFIG_PG_IDENT[] = "";
+static const char FILENAME_DATA[] = "data";
+static const char FILENAME_BACKUP[] = "backup";
 
 PostgresSelfHosted::PostgresSelfHosted()
 : m_network_shared(false)
@@ -170,7 +166,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
 
   if(m_database_directory_uri.empty())
   {
-    std::cerr << "PostgresSelfHosted::initialize: m_database_directory_uri is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": initialize: m_self_hosting_data_uri is empty." << std::endl;
     return INITERROR_OTHER;
   }
 
@@ -268,7 +264,6 @@ Glib::ustring PostgresSelfHosted::get_postgresql_utils_version(const SlotProgres
   //We want the characters at the end:
   const gchar VERSION_REGEX[] = "pg_ctl \\(PostgreSQL\\) (.*)";
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     regex = Glib::Regex::create(VERSION_REGEX);
@@ -278,15 +273,6 @@ Glib::ustring PostgresSelfHosted::get_postgresql_utils_version(const SlotProgres
     std::cerr << "Glom: Glib::Regex::create() failed: " << ex.what() << std::endl;
     return result;
   }
-  #else
-  std::auto_ptr<Glib::Error> ex;
-  regex = Glib::Regex::create(VERSION_REGEX, static_cast<Glib::RegexCompileFlags>(0), static_cast<Glib::RegexMatchFlags>(0), ex);
-  if(ex.get())
-  {
-    std::cerr << "Glom: Glib::Regex::create() failed: " << ex->what() << std::endl;
-    return result;
-  }
-  #endif
 
   if(!regex)
     return result;
@@ -320,7 +306,6 @@ float PostgresSelfHosted::get_postgresql_utils_version_as_number(const SlotProgr
   //We want the characters at the end:
   const gchar VERSION_REGEX[] = "^(\\d*)\\.(\\d*)";
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     regex = Glib::Regex::create(VERSION_REGEX);
@@ -330,15 +315,6 @@ float PostgresSelfHosted::get_postgresql_utils_version_as_number(const SlotProgr
     std::cerr << "Glom: Glib::Regex::create() failed: " << ex.what() << std::endl;
     return result;
   }
-  #else
-  std::auto_ptr<Glib::Error> ex;
-  regex = Glib::Regex::create(VERSION_REGEX, static_cast<Glib::RegexCompileFlags>(0), static_cast<Glib::RegexMatchFlags>(0), ex);
-  if(ex.get())
-  {
-    std::cerr << "Glom: Glib::Regex::create() failed: " << ex->what() << std::endl;
-    return result;
-  }
-  #endif
 
   if(!regex)
     return result;
@@ -394,7 +370,8 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
 
   if(!(file_exists_uri(dbdir_uri)))
   {
-    std::cerr << "ConnectionPool::create_self_hosting(): The directory could not be found: " << dbdir_uri << std::endl;
+    //TODO: Use a return enum or exception so we can tell the user about this:
+    std::cerr << G_STRFUNC << ": The data directory could not be found: " << dbdir_uri << std::endl;
     return STARTUPERROR_FAILED_UNKNOWN_REASON;
   }
 
@@ -423,12 +400,12 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   //Attempt to ensure that the config files are correct:
   set_network_shared(slot_progress, m_network_shared); //Creates pg_hba.conf and pg_ident.conf
 
-
   const unsigned int available_port = discover_first_free_port(PORT_POSTGRESQL_SELF_HOSTED_START, PORT_POSTGRESQL_SELF_HOSTED_END);
-  //std::cout << "ConnectionPool::create_self_hosting():() : debug: Available port for self-hosting: " << available_port << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ":() : debug: Available port for self-hosting: " << available_port << std::endl;
   if(available_port == 0)
   {
-    std::cerr << "ConnectionPool::create_self_hosting(): No port was available between " << PORT_POSTGRESQL_SELF_HOSTED_START << " and " << PORT_POSTGRESQL_SELF_HOSTED_END << std::endl;
+    //TODO: Use a return enum or exception so we can tell the user about this:
+    std::cerr << G_STRFUNC << ": No port was available between " << PORT_POSTGRESQL_SELF_HOSTED_START << " and " << PORT_POSTGRESQL_SELF_HOSTED_END << std::endl;
     return STARTUPERROR_FAILED_UNKNOWN_REASON;
   }
 
@@ -568,16 +545,14 @@ static bool on_timeout_delay(const Glib::RefPtr<Glib::MainLoop>& mainloop)
 }
 
 
-Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error)
+Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password)
 {
   if(!get_self_hosting_active())
   {
-    error.reset(new ExceptionConnection(ExceptionConnection::FAILURE_NO_BACKEND)); //TODO: But there is a backend. It's just not ready.
+    throw ExceptionConnection(ExceptionConnection::FAILURE_NO_BACKEND); //TODO: But there is a backend. It's just not ready.
     return Glib::RefPtr<Gnome::Gda::Connection>();
   }
 
-  std::auto_ptr<ExceptionConnection> ex;
-
   Glib::RefPtr<Gnome::Gda::Connection> result;
   bool keep_trying = true;
   guint count_retries = 0;
@@ -585,45 +560,53 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ust
   const guint MAX_RETRIES_EVER = 60; /* seconds */
   while(keep_trying)
   {
-    result = attempt_connect(port_as_string(m_port), database, username, password, ex);
-    if(!result &&
-      ex.get() && (ex->get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER))
+    try
     {
-      //It must be using a default password, so any failure would not be due to a wrong password.
-      //However, pg_ctl sometimes reports success before it is really ready to let us connect,
-      //so in this case we can just keep trying until it works, with a very long timeout.
-      count_retries++;
-      const guint max_retries = m_network_shared ? MAX_RETRIES_EVER : MAX_RETRIES_KNOWN_PASSWORD;
-      if(count_retries > max_retries)
+      result = attempt_connect(port_as_string(m_port), database, username, password);
+    }
+    catch(const ExceptionConnection& ex)
+    {
+      if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
       {
-        keep_trying = false;
+        //It must be using a default password, so any failure would not be due to a wrong password.
+        //However, pg_ctl sometimes reports success before it is really ready to let us connect,
+        //so in this case we can just keep trying until it works, with a very long timeout.
+        count_retries++;
+        const guint max_retries = m_network_shared ? MAX_RETRIES_EVER : MAX_RETRIES_KNOWN_PASSWORD;
+        if(count_retries > max_retries)
+        {
+          keep_trying = false;
+          continue;
+        }
+
+        std::cout << "debug: " << G_STRFUNC << ": Waiting and retrying the connection due to suspected too-early success of pg_ctl. retries=" << count_retries << ", max_retries=" << m_network_shared << std::endl;
+
+        //Wait:
+        Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
+          sigc::connection connection_timeout = Glib::signal_timeout().connect(
+          sigc::bind(sigc::ptr_fun(&on_timeout_delay), sigc::ref(mainloop)),
+          1000 /* 1 second */);
+        mainloop->run();
+        connection_timeout.disconnect();
+
+        keep_trying = true;
         continue;
       }
-
-      std::cout << "DEBUG: Glom::PostgresSelfHosted::connect(): Waiting and retrying the connection due to suspected too-early success of pg_ctl." << std::endl;
-
-      //Wait:
-      Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
-        sigc::connection connection_timeout = Glib::signal_timeout().connect(
-        sigc::bind(sigc::ptr_fun(&on_timeout_delay), sigc::ref(mainloop)),
-        1000 /* 1 second */);
-      mainloop->run();
-      connection_timeout.disconnect();
-
-      keep_trying = true;
-      continue;
+      else
+      {
+        throw ex;
+      }
     }
 
     keep_trying = false;
   }
 
-  error = ex;
   return result;
 }
 
-bool PostgresSelfHosted::create_database(const Glib::ustring& database_name, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<Glib::Error>& error)
+bool PostgresSelfHosted::create_database(const Glib::ustring& database_name, const Glib::ustring& username, const Glib::ustring& password)
 {
-  return attempt_create_database(database_name, m_host, port_as_string(m_port), username, password, error);
+  return attempt_create_database(database_name, "localhost", port_as_string(m_port), username, password);
 }
 
 unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_port, unsigned int end_port)
@@ -636,7 +619,7 @@ unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_por
     std::cerr << "Create socket: " << WSAGetLastError() << std::endl;
 #else
     perror("Create socket");
-#endif
+#endif //G_OS_WIN32
     return 0;
   }
 
@@ -674,7 +657,7 @@ unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_por
     }
     else
     {
-      //std::cout << "debug: ConnectionPool::discover_first_free_port(): port in use: " << port_to_try << std::endl;
+      //std::cout << "debug: " << G_STRFUNC << ": port in use: " << port_to_try << std::endl;
     }
 
     if(available)
@@ -685,7 +668,7 @@ unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_por
       close(fd);
       #endif //G_OS_WIN32
 
-      //std::cout << "debug: ConnectionPool::discover_first_free_port(): Found: returning " << port_to_try << std::endl;
+      //std::cout << "debug: " << G_STRFUNC << ": Found: returning " << port_to_try << std::endl;
       return port_to_try;
     }
 
@@ -696,9 +679,9 @@ unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_por
   closesocket(fd);
 #else
   close(fd);
-#endif
+#endif //G_OS_WIN32
 
-  std::cerr << "debug: ConnectionPool::discover_first_free_port(): No port was available." << std::endl;
+  std::cerr << G_STRFUNC << ": No port was available." << std::endl;
   return 0;
 }
 
