@@ -21,6 +21,7 @@
 #include "fieldformatting.h"
 #include <libglom/data_structure/layout/fieldformatting.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/document/document.h>
 #include <glibmm/i18n.h>
 
 const guint MULTILINE_TEXT_DEFAULT_HEIGHT_LINES = 6;
@@ -30,11 +31,13 @@ namespace Glom
 
 FieldFormatting::FieldFormatting()
 : m_choices_restricted(false),
+  m_choices_restricted_as_radio_buttons(false),
   m_choices_custom(false),
   m_choices_related(false),
   m_text_format_multiline(false),
   m_text_multiline_height_lines(MULTILINE_TEXT_DEFAULT_HEIGHT_LINES),
-  m_horizontal_alignment(HORIZONTAL_ALIGNMENT_AUTO)
+  m_horizontal_alignment(HORIZONTAL_ALIGNMENT_AUTO),
+  m_choices_related_show_all(true) //Because this a the simpler, more often useful, default.
 {
 }
 
@@ -43,6 +46,7 @@ FieldFormatting::FieldFormatting(const FieldFormatting& src)
   m_numeric_format(src.m_numeric_format),
   m_choices_custom_list(src.m_choices_custom_list),
   m_choices_restricted(src.m_choices_restricted),
+  m_choices_restricted_as_radio_buttons(src.m_choices_restricted_as_radio_buttons),
   m_choices_custom(src.m_choices_custom),
   m_choices_related(src.m_choices_related),
   m_text_format_multiline(src.m_text_format_multiline),
@@ -52,7 +56,8 @@ FieldFormatting::FieldFormatting(const FieldFormatting& src)
   m_text_color_background(src.m_text_color_background),
   m_horizontal_alignment(src.m_horizontal_alignment),
   m_choices_related_field(src.m_choices_related_field),
-  m_choices_related_field_second(src.m_choices_related_field_second)
+  m_choices_extra_layout_group(src.m_choices_extra_layout_group),
+  m_choices_related_show_all(src.m_choices_related_show_all)
 {
 }
 
@@ -66,16 +71,18 @@ bool FieldFormatting::operator==(const FieldFormatting& src) const
     (m_numeric_format == src.m_numeric_format) &&
     (m_choices_custom_list == src.m_choices_custom_list) &&
     (m_choices_restricted == src.m_choices_restricted) &&
+    (m_choices_restricted_as_radio_buttons == src.m_choices_restricted_as_radio_buttons) &&
     (m_choices_custom == src.m_choices_custom) &&
     (m_choices_related == src.m_choices_related) &&
     (m_choices_related_field == src.m_choices_related_field) &&
-    (m_choices_related_field_second == src.m_choices_related_field_second) &&
+    (m_choices_extra_layout_group == src.m_choices_extra_layout_group) &&
     (m_text_format_multiline == src.m_text_format_multiline) &&
     (m_text_multiline_height_lines == src.m_text_multiline_height_lines) &&
     (m_text_font == src.m_text_font) &&
     (m_text_color_foreground == src.m_text_color_foreground) &&
-    (m_text_color_background == src.m_text_color_background) && 
-    (m_horizontal_alignment == src.m_horizontal_alignment);
+    (m_text_color_background == src.m_text_color_background) &&
+    (m_horizontal_alignment == src.m_horizontal_alignment) &&
+    (m_choices_related_show_all == src.m_choices_related_show_all);
 }
 
 
@@ -87,10 +94,12 @@ FieldFormatting& FieldFormatting::operator=(const FieldFormatting& src)
 
   m_choices_custom_list = src.m_choices_custom_list;
   m_choices_restricted = src.m_choices_restricted;
+  m_choices_restricted_as_radio_buttons = src.m_choices_restricted_as_radio_buttons;
   m_choices_custom = src.m_choices_custom;
   m_choices_related = src.m_choices_related;
   m_choices_related_field = src.m_choices_related_field;
-  m_choices_related_field_second = src.m_choices_related_field_second;
+  m_choices_extra_layout_group = src.m_choices_extra_layout_group;
+  m_choices_related_show_all = src.m_choices_related_show_all;
 
   m_text_format_multiline = src.m_text_format_multiline;
   m_text_multiline_height_lines = src.m_text_multiline_height_lines;
@@ -181,7 +190,7 @@ FieldFormatting::HorizontalAlignment FieldFormatting::get_horizontal_alignment()
 
 bool FieldFormatting::get_has_choices() const
 {
-  return ( m_choices_related && get_has_relationship_name() && !m_choices_related_field.empty() ) ||
+  return ( m_choices_related && get_has_relationship_name() && m_choices_related_field ) ||
          ( m_choices_custom && !m_choices_custom_list.empty() );
 }
 
@@ -195,14 +204,16 @@ void FieldFormatting::set_choices_custom(const type_list_values& choices)
   m_choices_custom_list = choices;
 }
 
-bool FieldFormatting::get_choices_restricted() const
+bool FieldFormatting::get_choices_restricted(bool& as_radio_buttons) const
 {
+  as_radio_buttons = m_choices_restricted_as_radio_buttons;
   return m_choices_restricted;
 }
 
-void FieldFormatting::set_choices_restricted(bool val)
+void FieldFormatting::set_choices_restricted(bool val, bool as_radio_buttons)
 {
   m_choices_restricted = val;
+  m_choices_restricted_as_radio_buttons = as_radio_buttons;
 }
 
 bool FieldFormatting::get_has_custom_choices() const
@@ -220,40 +231,50 @@ bool FieldFormatting::get_has_related_choices() const
   return m_choices_related;
 }
 
+bool FieldFormatting::get_has_related_choices(bool& show_all, bool& with_second) const
+{
+  show_all = m_choices_related_show_all;
+  with_second = m_choices_extra_layout_group;
+  return m_choices_related;
+}
+
 void FieldFormatting::set_has_related_choices(bool val)
 {
   m_choices_related = val;
 }
 
-void FieldFormatting::get_choices(sharedptr<Relationship>& relationship, Glib::ustring& field, Glib::ustring& field_second) const
-{
-  relationship = get_relationship();
-
-  field = m_choices_related_field;
-  field_second = m_choices_related_field_second;
-
-  //g_warning("FieldFormatting::get_choices, %s, %s, %s", m_choices_related_relationship->c_str(), m_choices_related_field.c_str(), m_choices_related_field_second.c_str());
-}
-
-void FieldFormatting::set_choices(const sharedptr<Relationship>& relationship, const Glib::ustring& field, const Glib::ustring& field_second)
+void FieldFormatting::set_choices_related(const sharedptr<const Relationship>& relationship, const sharedptr<LayoutItem_Field>& field, const sharedptr<LayoutGroup>& extra_layout, bool show_all)
 {
   set_relationship(relationship);
 
   m_choices_related_field = field;
-  m_choices_related_field_second = field_second;
+  m_choices_extra_layout_group = extra_layout;
+  m_choices_related_show_all = show_all;
 }
 
-void FieldFormatting::change_field_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new)
+void FieldFormatting::get_choices_related(sharedptr<const Relationship>& relationship, sharedptr<const LayoutItem_Field>& field, sharedptr<const LayoutGroup>& extra_layout, bool& show_all) const
 {
-  //Update choices:
-  if(get_has_relationship_name() && get_table_used(Glib::ustring()) == table_name)
-  {
-    if(m_choices_related_field == field_name)
-       m_choices_related_field = field_name_new;
+  relationship = get_relationship();
 
-    if(m_choices_related_field_second == field_name)
-       m_choices_related_field_second = field_name_new; 
-  }
+  field = m_choices_related_field;
+  extra_layout = m_choices_extra_layout_group;
+  show_all = m_choices_related_show_all;
+}
+
+
+void FieldFormatting::get_choices_related(sharedptr<const Relationship>& relationship, sharedptr<LayoutItem_Field>& field, sharedptr<LayoutGroup>& extra_layout, bool& show_all)
+{
+  relationship = get_relationship();
+
+  field = m_choices_related_field;
+  extra_layout = m_choices_extra_layout_group;
+  show_all = m_choices_related_show_all;
+}
+
+sharedptr<const Relationship> FieldFormatting::get_choices_related_relationship(bool& show_all) const
+{
+  show_all = m_choices_related_show_all;
+  return get_relationship();
 }
 
 } //namespace Glom
