@@ -24,11 +24,13 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/utils_ui.h>
 #include <libglom/data_structure/layout/layoutitem_field.h>
-#include <glom/glom_privs.h>
+#include <libglom/privs.h>
 #include <glom/python_embed/glom_python.h>
+#include <glom/python_embed/python_ui_callbacks.h>
 #include <glom/application.h>
 #include <algorithm> //For std::find()
 #include <libglom/libglom_config.h>
+#include <iostream>
 #include <glibmm/i18n.h>
 
 #ifdef GLOM_ENABLE_MAEMO
@@ -84,15 +86,16 @@ FoundSet Box_Data::get_found_set() const
   return m_found_set;
 }
 
-Glib::ustring Box_Data::get_find_where_clause() const
+Gnome::Gda::SqlExpr Box_Data::get_find_where_clause() const
 {
-  Glib::ustring strClause;
+  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+    Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+  builder->select_add_target(m_table_name);  //This might not be necessary.
+  guint where_cond_id = 0;
 
   //Look at each field entry and build e.g. 'Name = "Bob"'
-  for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
+  for(type_vecConstLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
   {
-    Glib::ustring strClausePart;
-
     const Gnome::Gda::Value data = get_entered_field_data(*iter);
 
     if(!Conversions::value_is_empty(data))
@@ -109,22 +112,31 @@ Glib::ustring Box_Data::get_find_where_clause() const
 
         if(use_this_field)
         {
-          //TODO: Use a SQL parameter instead of using sql_find().
-          strClausePart = "\"" + m_table_name + "\".\"" + field->get_name() + "\" " + field->sql_find_operator() + " " +  field->sql_find(data); //% is mysql wildcard for 0 or more characters.
+          const guint cond_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ, //TODO: Use field->sql_find_operator()
+            builder->add_field_id(field->get_name(), m_table_name),
+            builder->add_expr(data));
+
+          //And with previous condition, if any:
+          if(where_cond_id)
+          {
+            where_cond_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND, //TODO: Use field->sql_find_operator()
+              where_cond_id,
+              cond_id);
+          }
+          else
+            where_cond_id = cond_id;
         }
       }
     }
-
-    if(!strClausePart.empty())
-    {
-      if(!strClause.empty())
-        strClause += "AND ";
-
-      strClause += '(' + strClausePart + ") ";
-    }
   }
 
-  return strClause;
+  if(where_cond_id)
+  {
+    builder->set_where(where_cond_id); //This might not be necessary.
+    return builder->export_expression(where_cond_id);
+  }
+  else
+    return Gnome::Gda::SqlExpr();
 }
 
 void Box_Data::on_Button_Find()
@@ -132,10 +144,10 @@ void Box_Data::on_Button_Find()
   //Make sure that the cell is updated:
   //m_AddDel.finish_editing();
 
-  const Glib::ustring where_clause = get_find_where_clause();
+  const Gnome::Gda::SqlExpr where_clause = get_find_where_clause();
   if(where_clause.empty())
   {
-    Glib::ustring message = _("You have not entered any find criteria. Try entering information in the fields.");
+    const Glib::ustring message = _("You have not entered any find criteria. Try entering information in the fields.");
 
 #ifdef GLOM_ENABLE_MAEMO
     Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, *get_app_window(), message);
@@ -225,17 +237,17 @@ void Box_Data::on_dialog_layout_hide()
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-Box_Data::type_vecLayoutFields Box_Data::get_fields_to_show() const
+Box_Data::type_vecConstLayoutFields Box_Data::get_fields_to_show() const
 {
   if(m_table_name.empty())
   {
-    return type_vecLayoutFields();
+    return type_vecConstLayoutFields();
   }
   else
     return get_table_fields_to_show(m_table_name);
 }
 
-Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::ustring& table_name) const
+Box_Data::type_vecConstLayoutFields Box_Data::get_table_fields_to_show(const Glib::ustring& table_name) const
 {
   const Document* pDoc = dynamic_cast<const Document*>(get_document());
   if(pDoc)
@@ -244,7 +256,7 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
     return get_table_fields_to_show_for_sequence(table_name, mapGroupSequence);
   }
   else
-    return type_vecLayoutFields();
+    return type_vecConstLayoutFields();
 }
 
 Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& layout_platform)
@@ -258,7 +270,7 @@ Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::u
     {
       //Get the layout information from the document:
       layout_groups = document->get_data_layout_groups_plus_new_fields(layout_name, m_table_name, layout_platform);
-
+      document->fill_layout_field_details(m_table_name, layout_groups); //TODO: Do this automatically in Document?
       const Privileges table_privs = Privs::get_current_privs(m_table_name);
 
       //Fill in the field information for the fields mentioned in the layout:
@@ -351,55 +363,29 @@ Glib::ustring Box_Data::get_layout_name() const
   return m_layout_name;
 }
 
-void Box_Data::on_python_requested_show_table_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value)
-{
-  std::cout << "debug: on_python_requested_show_table_details(): " << table_name << ", pk value: " << primary_key_value.to_string() << std::endl;
-  
-  Application* app = Application::get_application();
-  if(app)
-    app->show_table_details(table_name, primary_key_value);
-}
-
-void Box_Data::on_python_requested_show_table_list(const Glib::ustring& table_name)
-{
-  //std::cout << "debug: on_python_requested_show_table_list(): " << table_name << std::endl;
-  
-  Application* app = Application::get_application();
-  if(app)
-    app->show_table_list(table_name);
-}
-  
 void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value)
 {
   const sharedptr<Field> field_primary_key = get_field_primary_key();
   const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, field_primary_key, primary_key_value);
 
   //We need the connection when we run the script, so that the script may use it.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
-#else
-  std::auto_ptr<ExceptionConnection> error;
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */, error);
-  if(!error.get())
-  {
-#endif // GLIBMM_EXCEPTIONS_ENABLED
 
     //Allow this UI to respond to UI change requests from the Python code:
-    PythonUICallbacks callbacks;
-    callbacks.m_slot_show_table_details = 
-      sigc::mem_fun(*this, &Box_Data::on_python_requested_show_table_details);
-    callbacks.m_slot_show_table_list = 
-      sigc::mem_fun(*this, &Box_Data::on_python_requested_show_table_list);
-          
+    AppPythonUICallbacks callbacks;
+
+    Glib::ustring error_message;
     glom_execute_python_function_implementation(layout_item->get_script(),
       field_values, //TODO: Maybe use the field's type here.
       get_document(),
       get_table_name(), field_primary_key, primary_key_value,
       sharedconnection->get_gda_connection(),
-      callbacks);
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-  }
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
+      callbacks,
+      error_message);
+    if(!error_message.empty())
+    {
+      std::cerr << "Python Error: " << error_message << std::endl;
+    }
 }
 
 } //namespace Glom
