@@ -146,11 +146,8 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
     default_value = m_Field->get_default_value();
 
   //Create an appropriate DataWidget for the default value:
-  if(m_pDataWidget_DefaultValueSimple)
-  {
-    delete m_pDataWidget_DefaultValueSimple;
-    m_pDataWidget_DefaultValueSimple = 0;
-  }
+  delete m_pDataWidget_DefaultValueSimple;
+  m_pDataWidget_DefaultValueSimple = 0;
 
   //We use a regular DataWidget for the default value, so we can reuse its functionality,
   //but it's not a real field - hence the special title.
@@ -368,7 +365,7 @@ void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
         const type_vec_fields fields_in_to_table = get_fields_for_table(to_table);
         for(type_vec_fields::const_iterator iter = fields_in_to_table.begin(); iter != fields_in_to_table.end(); ++iter)
         {
-          m_pCombo_LookupField->append_text((*iter)->get_name());
+          m_pCombo_LookupField->append((*iter)->get_name());
         }
       }
     }
