@@ -24,7 +24,7 @@
 #include "canvas_image_movable.h"
 #include <goocanvasmm/canvas.h>
 #include <gtkmm/stock.h>
-#include <glom/utility_widgets/imageglom.h> //For ImageGlom::scale_keeping_ratio().
+#include <glom/utils_ui.h> //For Utils::image_scale_keeping_ratio().
 #include <iostream>
 
 namespace Glom
@@ -72,24 +72,14 @@ Glib::RefPtr<CanvasImageMovable> CanvasImageMovable::create(double x, double y)
 
 void CanvasImageMovable::get_xy(double& x, double& y) const
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   x = property_x();
   y = property_y();
-#else
-  get_property("x", x);
-  get_property("y", y);
-#endif
 }
 
 void CanvasImageMovable::set_xy(double x, double y)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_x() = x;
   property_y() = y;
-#else
-  set_property("x", x);
-  set_property("y", y);
-#endif
 }
 
 void CanvasImageMovable::get_width_height(double& width, double& height) const
@@ -97,24 +87,14 @@ void CanvasImageMovable::get_width_height(double& width, double& height) const
   //TODO: This only works when it is on a canvas already,
   //and this is apparently incorrect when the "coordinate space" of the item changes, whatever that means. murrayc.
   
-#ifdef GLIBMM_PROPERTIES_ENABLED
   width = property_width();
   height = property_height();
-#else
-  get_property("width", width);
-  get_property("height", height);
-#endif 
 }
 
 void CanvasImageMovable::set_width_height(double width, double height)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_width() = width;
   property_height() = height;
-#else
-  set_property("width", width);
-  set_property("height", height);
-#endif 
 }
 
 void CanvasImageMovable::snap_position(double& x, double& y) const
@@ -133,11 +113,7 @@ void CanvasImageMovable::snap_position(double& x, double& y) const
       corner_y_offset = 0;
       break;
     case CORNER_TOP_RIGHT:
-#ifdef GLIBMM_PROPERTIES_ENABLED    
       corner_x_offset = property_width();
-#else
-      get_property("width", corner_x_offset);
-#endif      
       corner_y_offset = 0;
       break;
     case CORNER_BOTTOM_LEFT:
@@ -180,11 +156,7 @@ void CanvasImageMovable::set_snap_corner(Corners corner)
 
 void CanvasImageMovable::set_image(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf, bool scale)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_pixbuf() = pixbuf;
-#else
-  set_property("pixbuf", pixbuf);
-#endif    
   m_pixbuf = pixbuf;
 
   if(scale)
@@ -201,16 +173,12 @@ void CanvasImageMovable::scale_to_size()
   double width = 0;
   double height = 0;
   get_width_height(width, height);
-  //std::cout << "CanvasImageMovable::set_image(): width=" << width << ", height=" << height << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": width=" << width << ", height=" << height << std::endl;
   
   if(width && height)
   {
-    Glib::RefPtr<Gdk::Pixbuf> pixbuf = ImageGlom::scale_keeping_ratio(m_pixbuf, (int)height, (int)width);
-#ifdef GLIBMM_PROPERTIES_ENABLED
+    Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::image_scale_keeping_ratio(m_pixbuf, (int)height, (int)width);
     property_pixbuf() = pixbuf;
-#else
-    set_property("pixbuf", pixbuf);
-#endif 
   }
 
   //Make sure that the size stays the same even if the scaling wasn't exact:
@@ -225,16 +193,12 @@ void CanvasImageMovable::set_image_empty()
   Gtk::Widget *widget = get_canvas();
 
   if(!widget)
-    widget = App_Glom::get_application();
+    widget = Application::get_application();
 
   Glib::RefPtr<Gdk::Pixbuf> pixbuf;
   if(widget)
-    pixbuf = widget->render_icon(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
-#ifdef GLIBMM_PROPERTIES_ENABLED
+    pixbuf = widget->render_icon_pixbuf(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
     property_pixbuf() = pixbuf;
-#else
-    set_property("pixbuf", pixbuf);
-#endif
 }
 
 bool CanvasImageMovable::get_image_empty() const
